==> ejc-bid-api-3.0.0-20221019.024546-289-sources.jar: com/ejianc/business/bid/vo/UndertakeVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 承揽任务登记
 * 
 * @author generator
 * 
 */
public class UndertakeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String operatorCode; // 经办人联系方式
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long makeOrgId; // 编制部门ID
    private String makeOrgName; // 编制部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeTime; // 编制时间
    private Long projectId; // 工程id
    private String porjectName; // 工程名称
    private Long specialityId; // 工程类别id
    private String specialityName; // 工程类别类别名称
    private String projectRemark; // 工程概况
    private String projectQuality; // 工程质量
    private BigDecimal projectCost; // 工程造价
    private BigDecimal days; // 工期（日历天）
    private Long jzsId; // 建造师id
    private String jzsName; // 建造师名称
    private Long xmnbcbrId; // 项目内部承包人id
    private String xmnbcbrName; // 项目内部承包人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sqTime; // 申请时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date zbTime; // 中标时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htgzrqTime; // 合同盖章时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htbjrqTime; // 合同办结时间
    private String gzzt; // 跟踪状态
    private String xgsm; // 相关说明
    private BigDecimal zjzmj; // 总建筑面积
    private Long jgxsId; // 结构形式id
    private String jgxsName; // 结构形式
    private Long enrollId; // 投标报名
    private String contractType; // 合同类型
    private String contractStatus; // 合同状态
    private BigDecimal zzje; // 最终金额
    private Integer year; // 年份
    private Integer month; // 月份
    private Long contractId; // 合同id
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private BigDecimal contractMoney; // 合同金额
    private String orgCode; // 组织编号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ywDate; // 业务时间
    private String area; // 地区
    private String areaName; // 地区名称
    private String specialityCode; // 工程类别类别编号
    private Integer supplementFlag; // 补充协议标识
    private Long mainId; // 合同id
    private List<UndertakeVO> children;


    public List<UndertakeVO> getChildren() {
        return children;
    }

    public void setChildren(List<UndertakeVO> children) {
        this.children = children;
    }

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }

    public Integer getSupplementFlag() {
        return supplementFlag;
    }

    public void setSupplementFlag(Integer supplementFlag) {
        this.supplementFlag = supplementFlag;
    }

    public String getSpecialityCode() {
        return specialityCode;
    }

    public void setSpecialityCode(String specialityCode) {
        this.specialityCode = specialityCode;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Date getYwDate() {
        return ywDate;
    }

    public void setYwDate(Date ywDate) {
        this.ywDate = ywDate;
    }


    @ReferSerialTransfer(referCode = "proincome-contract-review")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public BigDecimal getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(BigDecimal contractMoney) {
        this.contractMoney = contractMoney;
    }
    @ReferSerialTransfer(referCode = "bid-enroll")
    public Long getEnrollId() {
        return enrollId;
    }
    @ReferDeserialTransfer
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public BigDecimal getZzje() {
        return zzje;
    }

    public void setZzje(BigDecimal zzje) {
        this.zzje = zzje;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getMakeOrgId() {
        return makeOrgId;
    }
    @ReferDeserialTransfer
    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    public String getMakeOrgName() {
        return makeOrgName;
    }

    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    public Date getMakeTime() {
        return makeTime;
    }

    public void setMakeTime(Date makeTime) {
        this.makeTime = makeTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPorjectName() {
        return porjectName;
    }

    public void setPorjectName(String porjectName) {
        this.porjectName = porjectName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSpecialityId() {
        return specialityId;
    }
    @ReferDeserialTransfer
    public void setSpecialityId(Long specialityId) {
        this.specialityId = specialityId;
    }
    public String getSpecialityName() {
        return specialityName;
    }

    public void setSpecialityName(String specialityName) {
        this.specialityName = specialityName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }
    public String getProjectQuality() {
        return projectQuality;
    }

    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    public BigDecimal getProjectCost() {
        return projectCost;
    }

    public void setProjectCost(BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    public BigDecimal getDays() {
        return days;
    }

    public void setDays(BigDecimal days) {
        this.days = days;
    }
    public Long getJzsId() {
        return jzsId;
    }

    public void setJzsId(Long jzsId) {
        this.jzsId = jzsId;
    }
    public String getJzsName() {
        return jzsName;
    }

    public void setJzsName(String jzsName) {
        this.jzsName = jzsName;
    }
    public Long getXmnbcbrId() {
        return xmnbcbrId;
    }

    public void setXmnbcbrId(Long xmnbcbrId) {
        this.xmnbcbrId = xmnbcbrId;
    }
    public String getXmnbcbrName() {
        return xmnbcbrName;
    }

    public void setXmnbcbrName(String xmnbcbrName) {
        this.xmnbcbrName = xmnbcbrName;
    }
    public Date getSqTime() {
        return sqTime;
    }

    public void setSqTime(Date sqTime) {
        this.sqTime = sqTime;
    }
    public Date getZbTime() {
        return zbTime;
    }

    public void setZbTime(Date zbTime) {
        this.zbTime = zbTime;
    }
    public Date getHtgzrqTime() {
        return htgzrqTime;
    }

    public void setHtgzrqTime(Date htgzrqTime) {
        this.htgzrqTime = htgzrqTime;
    }
    public Date getHtbjrqTime() {
        return htbjrqTime;
    }

    public void setHtbjrqTime(Date htbjrqTime) {
        this.htbjrqTime = htbjrqTime;
    }
    public String getGzzt() {
        return gzzt;
    }

    public void setGzzt(String gzzt) {
        this.gzzt = gzzt;
    }
    public String getXgsm() {
        return xgsm;
    }

    public void setXgsm(String xgsm) {
        this.xgsm = xgsm;
    }
    public BigDecimal getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(BigDecimal zjzmj) {
        this.zjzmj = zjzmj;
    }
    public Long getJgxsId() {
        return jgxsId;
    }

    public void setJgxsId(Long jgxsId) {
        this.jgxsId = jgxsId;
    }
    public String getJgxsName() {
        return jgxsName;
    }

    public void setJgxsName(String jgxsName) {
        this.jgxsName = jgxsName;
    }
    
}

==> ejc-bid-api-3.0.0-20250514.100053-438-sources.jar: com/ejianc/business/bid/vo/UndertakeVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 承揽任务登记
 * 
 * @author generator
 * 
 */
public class UndertakeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String operatorCode; // 经办人联系方式
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long makeOrgId; // 编制部门ID
    private String makeOrgName; // 编制部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeTime; // 编制时间
    private Long projectId; // 工程id
    private String porjectName; // 工程名称
    private Long specialityId; // 工程类别id
    private String specialityName; // 工程类别类别名称
    private String projectRemark; // 工程概况
    private String projectQuality; // 工程质量
    private BigDecimal projectCost; // 工程造价
    private BigDecimal days; // 工期（日历天）
    private Long jzsId; // 建造师id
    private String jzsName; // 建造师名称
    private Long xmnbcbrId; // 项目内部承包人id
    private String xmnbcbrName; // 项目内部承包人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sqTime; // 申请时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date zbTime; // 中标时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htgzrqTime; // 合同盖章时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date htbjrqTime; // 合同办结时间
    private String gzzt; // 跟踪状态
    private String xgsm; // 相关说明
    private BigDecimal zjzmj; // 总建筑面积
    private Long jgxsId; // 结构形式id
    private String jgxsName; // 结构形式
    private Long enrollId; // 投标报名
    private String contractType; // 合同类型
    private String contractStatus; // 合同状态
    private BigDecimal zzje; // 最终金额
    private Integer year; // 年份
    private Integer month; // 月份
    private Long contractId; // 合同id
    private String contractCode; // 合同编号
    private String contractName; // 合同名称
    private BigDecimal contractMoney; // 合同金额
    private String orgCode; // 组织编号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ywDate; // 业务时间
    private String area; // 地区
    private String areaName; // 地区名称
    private String specialityCode; // 工程类别类别编号
    private Integer supplementFlag; // 补充协议标识
    private Long mainId; // 合同id
    private List<UndertakeVO> children;
    private String constructionUnitName; // 建设单位名称


    public String getConstructionUnitName() {
        return constructionUnitName;
    }

    public void setConstructionUnitName(String constructionUnitName) {
        this.constructionUnitName = constructionUnitName;
    }

    public List<UndertakeVO> getChildren() {
        return children;
    }

    public void setChildren(List<UndertakeVO> children) {
        this.children = children;
    }

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }

    public Integer getSupplementFlag() {
        return supplementFlag;
    }

    public void setSupplementFlag(Integer supplementFlag) {
        this.supplementFlag = supplementFlag;
    }

    public String getSpecialityCode() {
        return specialityCode;
    }

    public void setSpecialityCode(String specialityCode) {
        this.specialityCode = specialityCode;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Date getYwDate() {
        return ywDate;
    }

    public void setYwDate(Date ywDate) {
        this.ywDate = ywDate;
    }


    @ReferSerialTransfer(referCode = "proincome-contract-review")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public BigDecimal getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(BigDecimal contractMoney) {
        this.contractMoney = contractMoney;
    }
    @ReferSerialTransfer(referCode = "bid-enroll")
    public Long getEnrollId() {
        return enrollId;
    }
    @ReferDeserialTransfer
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public BigDecimal getZzje() {
        return zzje;
    }

    public void setZzje(BigDecimal zzje) {
        this.zzje = zzje;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getMakeOrgId() {
        return makeOrgId;
    }
    @ReferDeserialTransfer
    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    public String getMakeOrgName() {
        return makeOrgName;
    }

    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    public Date getMakeTime() {
        return makeTime;
    }

    public void setMakeTime(Date makeTime) {
        this.makeTime = makeTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPorjectName() {
        return porjectName;
    }

    public void setPorjectName(String porjectName) {
        this.porjectName = porjectName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSpecialityId() {
        return specialityId;
    }
    @ReferDeserialTransfer
    public void setSpecialityId(Long specialityId) {
        this.specialityId = specialityId;
    }
    public String getSpecialityName() {
        return specialityName;
    }

    public void setSpecialityName(String specialityName) {
        this.specialityName = specialityName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }
    public String getProjectQuality() {
        return projectQuality;
    }

    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    public BigDecimal getProjectCost() {
        return projectCost;
    }

    public void setProjectCost(BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    public BigDecimal getDays() {
        return days;
    }

    public void setDays(BigDecimal days) {
        this.days = days;
    }
    public Long getJzsId() {
        return jzsId;
    }

    public void setJzsId(Long jzsId) {
        this.jzsId = jzsId;
    }
    public String getJzsName() {
        return jzsName;
    }

    public void setJzsName(String jzsName) {
        this.jzsName = jzsName;
    }
    public Long getXmnbcbrId() {
        return xmnbcbrId;
    }

    public void setXmnbcbrId(Long xmnbcbrId) {
        this.xmnbcbrId = xmnbcbrId;
    }
    public String getXmnbcbrName() {
        return xmnbcbrName;
    }

    public void setXmnbcbrName(String xmnbcbrName) {
        this.xmnbcbrName = xmnbcbrName;
    }
    public Date getSqTime() {
        return sqTime;
    }

    public void setSqTime(Date sqTime) {
        this.sqTime = sqTime;
    }
    public Date getZbTime() {
        return zbTime;
    }

    public void setZbTime(Date zbTime) {
        this.zbTime = zbTime;
    }
    public Date getHtgzrqTime() {
        return htgzrqTime;
    }

    public void setHtgzrqTime(Date htgzrqTime) {
        this.htgzrqTime = htgzrqTime;
    }
    public Date getHtbjrqTime() {
        return htbjrqTime;
    }

    public void setHtbjrqTime(Date htbjrqTime) {
        this.htbjrqTime = htbjrqTime;
    }
    public String getGzzt() {
        return gzzt;
    }

    public void setGzzt(String gzzt) {
        this.gzzt = gzzt;
    }
    public String getXgsm() {
        return xgsm;
    }

    public void setXgsm(String xgsm) {
        this.xgsm = xgsm;
    }
    public BigDecimal getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(BigDecimal zjzmj) {
        this.zjzmj = zjzmj;
    }
    public Long getJgxsId() {
        return jgxsId;
    }

    public void setJgxsId(Long jgxsId) {
        this.jgxsId = jgxsId;
    }
    public String getJgxsName() {
        return jgxsName;
    }

    public void setJgxsName(String jgxsName) {
        this.jgxsName = jgxsName;
    }
    
}
